const directiveHandlers: DirectiveHandlers = {
    TAG (state__2, _name__2, ...args__2: string[]): void {
        const handle__2 = args__2[0];
        if (!PATTERN_TAG_HANDLE.test(handle__2)) {}
    }
};
